``eradiate.test_tools``
=======================

.. automodule:: eradiate.test_tools

``eradiate.test_tools.plugin``
------------------------------

.. automodule:: eradiate.test_tools.plugin

.. currentmodule:: eradiate.test_tools.plugin

.. autosummary::
   :toctree: generated/autosummary/

   sample_eval_pdf_bsdf


``eradiate.test_tools.regression``
----------------------------------

.. automodule:: eradiate.test_tools.regression

.. currentmodule:: eradiate.test_tools.regression

.. autosummary::
   :toctree: generated/autosummary/

   RegressionTest
   RMSETest
   Chi2Test


``eradiate.test_tools.types``
----------------------------------

.. automodule:: eradiate.test_tools.types

.. currentmodule:: eradiate.test_tools.types

.. autosummary::
   :toctree: generated/autosummary/

   check_scene_element
